Class AssistantThreadsSetStatusRequest
java.lang.Object
com.slack.api.methods.request.assistant.threads.AssistantThreadsSetStatusRequest
- All Implemented Interfaces:
SlackApiRequest
https://docs.slack.dev/reference/methods/assistant.threads.setStatus
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic class -
Method Summary
Modifier and TypeMethodDescriptionbuilder()protected booleanbooleanChannel ID containing the assistant thread.The list of messages to rotate through as a loading indicator.Status of the specified bot user, e.g.Message timestamp of the thread of where to set the status.getToken()Returns a token in this request object.inthashCode()voidsetChannelId(String channelId) Channel ID containing the assistant thread.voidsetLoadingMessages(List<String> loadingMessages) The list of messages to rotate through as a loading indicator.voidStatus of the specified bot user, e.g.voidsetThreadTs(String threadTs) Message timestamp of the thread of where to set the status.voidUpdates the token in this request object.toString()
-
Method Details
-
builder
-
getToken
Description copied from interface:SlackApiRequestReturns a token in this request object. If the API endpoint does not require a token (e.g., api.test), this method can return null.- Specified by:
getTokenin interfaceSlackApiRequest- Returns:
- token string value or null
-
getChannelId
Channel ID containing the assistant thread. -
getThreadTs
Message timestamp of the thread of where to set the status. -
getStatus
Status of the specified bot user, e.g. 'is thinking...' -
getLoadingMessages
The list of messages to rotate through as a loading indicator. -
setToken
Description copied from interface:SlackApiRequestUpdates the token in this request object.The default implementation throws
UnsupportedOperationException. All the built-in implementing classes overrides this method in a proper way.- Specified by:
setTokenin interfaceSlackApiRequest
-
setChannelId
Channel ID containing the assistant thread. -
setThreadTs
Message timestamp of the thread of where to set the status. -
setStatus
Status of the specified bot user, e.g. 'is thinking...' -
setLoadingMessages
The list of messages to rotate through as a loading indicator. -
equals
-
canEqual
-
hashCode
public int hashCode() -
toString
-