Class AssistantThreadsSetStatusRequest.AssistantThreadsSetStatusRequestBuilder
java.lang.Object
com.slack.api.methods.request.assistant.threads.AssistantThreadsSetStatusRequest.AssistantThreadsSetStatusRequestBuilder
- Enclosing class:
- AssistantThreadsSetStatusRequest
public static class AssistantThreadsSetStatusRequest.AssistantThreadsSetStatusRequestBuilder
extends Object
-
Method Summary
Modifier and TypeMethodDescriptionbuild()Channel ID containing the assistant thread.loadingMessages(List<String> loadingMessages) The list of messages to rotate through as a loading indicator.Status of the specified bot user, e.g.Message timestamp of the thread of where to set the status.toString()
-
Method Details
-
token
- Returns:
this.
-
channelId
public AssistantThreadsSetStatusRequest.AssistantThreadsSetStatusRequestBuilder channelId(String channelId) Channel ID containing the assistant thread.- Returns:
this.
-
threadTs
public AssistantThreadsSetStatusRequest.AssistantThreadsSetStatusRequestBuilder threadTs(String threadTs) Message timestamp of the thread of where to set the status.- Returns:
this.
-
status
public AssistantThreadsSetStatusRequest.AssistantThreadsSetStatusRequestBuilder status(String status) Status of the specified bot user, e.g. 'is thinking...'- Returns:
this.
-
loadingMessages
public AssistantThreadsSetStatusRequest.AssistantThreadsSetStatusRequestBuilder loadingMessages(List<String> loadingMessages) The list of messages to rotate through as a loading indicator.- Returns:
this.
-
build
-
toString
-