Class ChatUpdateRequest
java.lang.Object
com.slack.api.methods.request.chat.ChatUpdateRequest
- All Implemented Interfaces:
SlackApiRequest
https://docs.slack.dev/reference/methods/chat.update
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()protected booleanbooleanA JSON-based array of structured attachments, presented as a URL-encoded string.A JSON-based array of structured attachments, presented as a URL-encoded string.A JSON-based array of structured blocks, presented as a URL-encoded string.A JSON-based array of structured blocks as a String, presented as a URL-encoded string.Channel, private group, or IM channel to send message to.Array of new file ids that will be sent with this message.Accepts message text formatted in markdown.JSON object with event_type and event_payload fields, presented as a URL-encoded string.JSON object with event_type and event_payload fields, presented as a URL-encoded string.getParse()Change how messages are treated.getText()Text of the message to send.getToken()Authentication token.getTs()Timestamp of the message to be updated.getUser()`id` of the user who will receive the ephemeral message.inthashCode()isAsUser()booleanFind and link channel names and usernames.voidvoidsetAttachments(List<Attachment> attachments) A JSON-based array of structured attachments, presented as a URL-encoded string.voidsetAttachmentsAsString(String attachmentsAsString) A JSON-based array of structured attachments, presented as a URL-encoded string.voidsetBlocks(List<LayoutBlock> blocks) A JSON-based array of structured blocks, presented as a URL-encoded string.voidsetBlocksAsString(String blocksAsString) A JSON-based array of structured blocks as a String, presented as a URL-encoded string.voidsetChannel(String channel) Channel, private group, or IM channel to send message to.voidsetFileIds(List<String> fileIds) Array of new file ids that will be sent with this message.voidsetLinkNames(boolean linkNames) Find and link channel names and usernames.voidsetMarkdownText(String markdownText) Accepts message text formatted in markdown.voidsetMetadata(Message.Metadata metadata) JSON object with event_type and event_payload fields, presented as a URL-encoded string.voidsetMetadataAsString(String metadataAsString) JSON object with event_type and event_payload fields, presented as a URL-encoded string.voidChange how messages are treated.voidsetReplyBroadcast(Boolean replyBroadcast) voidText of the message to send.voidAuthentication token.voidTimestamp of the message to be updated.void`id` of the user who will receive the ephemeral message.toString()
-
Method Details
-
isReplyBroadcast
-
setReplyBroadcast
-
isAsUser
-
setAsUser
-
builder
-
getToken
Authentication token. Requires scope: `chat:write`- Specified by:
getTokenin interfaceSlackApiRequest- Returns:
- token string value or null
-
getChannel
Channel, private group, or IM channel to send message to. Can be an encoded ID, or a name. -
getTs
Timestamp of the message to be updated. -
getText
Text of the message to send. See below for an explanation of [formatting](#formatting). This field is usually required, unless you're providing only `attachments` instead. -
getUser
`id` of the user who will receive the ephemeral message. The user should be in the channel specified by the `channel` argument. -
getMarkdownText
Accepts message text formatted in markdown. This argument should not be used in conjunction with blocks or text. Limit this field to 12,000 characters. -
getMetadata
JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace. -
getMetadataAsString
JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace. -
getBlocks
A JSON-based array of structured blocks, presented as a URL-encoded string. -
getBlocksAsString
A JSON-based array of structured blocks as a String, presented as a URL-encoded string. -
getAttachments
A JSON-based array of structured attachments, presented as a URL-encoded string. -
getAttachmentsAsString
A JSON-based array of structured attachments, presented as a URL-encoded string. -
getFileIds
Array of new file ids that will be sent with this message. -
isLinkNames
public boolean isLinkNames()Find and link channel names and usernames. -
getParse
Change how messages are treated. Defaults to `none`. See [below](#formatting). -
setToken
Authentication token. Requires scope: `chat:write`- Specified by:
setTokenin interfaceSlackApiRequest
-
setChannel
Channel, private group, or IM channel to send message to. Can be an encoded ID, or a name. -
setTs
Timestamp of the message to be updated. -
setText
Text of the message to send. See below for an explanation of [formatting](#formatting). This field is usually required, unless you're providing only `attachments` instead. -
setUser
`id` of the user who will receive the ephemeral message. The user should be in the channel specified by the `channel` argument. -
setMarkdownText
Accepts message text formatted in markdown. This argument should not be used in conjunction with blocks or text. Limit this field to 12,000 characters. -
setMetadata
JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace. -
setMetadataAsString
JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace. -
setBlocks
A JSON-based array of structured blocks, presented as a URL-encoded string. -
setBlocksAsString
A JSON-based array of structured blocks as a String, presented as a URL-encoded string. -
setAttachments
A JSON-based array of structured attachments, presented as a URL-encoded string. -
setAttachmentsAsString
A JSON-based array of structured attachments, presented as a URL-encoded string. -
setFileIds
Array of new file ids that will be sent with this message. -
setLinkNames
public void setLinkNames(boolean linkNames) Find and link channel names and usernames. -
setParse
Change how messages are treated. Defaults to `none`. See [below](#formatting). -
equals
-
canEqual
-
hashCode
public int hashCode() -
toString
-