Class WorkflowsFeaturedSetRequest

java.lang.Object
com.slack.api.methods.request.workflows.WorkflowsFeaturedSetRequest
All Implemented Interfaces:
SlackApiRequest

public class WorkflowsFeaturedSetRequest extends Object implements SlackApiRequest
https://docs.slack.dev/reference/methods/workflows.featured.set/
  • Method Details

    • builder

    • getToken

      public String getToken()
      Authentication token bearing required scopes.
      Specified by:
      getToken in interface SlackApiRequest
      Returns:
      token string value or null
    • getChannelId

      public String getChannelId()
      Channel to set featured workflows in.
    • getTriggerIds

      public List<String> getTriggerIds()
      Comma-separated array of trigger IDs that will replace any existing featured workflows in the channel; max 15
    • setToken

      public void setToken(String token)
      Authentication token bearing required scopes.
      Specified by:
      setToken in interface SlackApiRequest
    • setChannelId

      public void setChannelId(String channelId)
      Channel to set featured workflows in.
    • setTriggerIds

      public void setTriggerIds(List<String> triggerIds)
      Comma-separated array of trigger IDs that will replace any existing featured workflows in the channel; max 15
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • canEqual

      protected boolean canEqual(Object other)
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object