Class WorkflowsFeaturedSetRequest.WorkflowsFeaturedSetRequestBuilder
java.lang.Object
com.slack.api.methods.request.workflows.WorkflowsFeaturedSetRequest.WorkflowsFeaturedSetRequestBuilder
- Enclosing class:
- WorkflowsFeaturedSetRequest
-
Method Summary
Modifier and TypeMethodDescriptionbuild()Channel to set featured workflows in.Authentication token bearing required scopes.toString()triggerIds(List<String> triggerIds) Comma-separated array of trigger IDs that will replace any existing featured workflows in the channel; max 15
-
Method Details
-
token
Authentication token bearing required scopes.- Returns:
this.
-
channelId
Channel to set featured workflows in.- Returns:
this.
-
triggerIds
public WorkflowsFeaturedSetRequest.WorkflowsFeaturedSetRequestBuilder triggerIds(List<String> triggerIds) Comma-separated array of trigger IDs that will replace any existing featured workflows in the channel; max 15- Returns:
this.
-
build
-
toString
-