Class WorkflowsFeaturedSetRequest
java.lang.Object
com.slack.api.methods.request.workflows.WorkflowsFeaturedSetRequest
- All Implemented Interfaces:
SlackApiRequest
https://docs.slack.dev/reference/methods/workflows.featured.set/
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic class -
Method Summary
Modifier and TypeMethodDescriptionbuilder()protected booleanbooleanChannel to set featured workflows in.getToken()Authentication token bearing required scopes.Comma-separated array of trigger IDs that will replace any existing featured workflows in the channel; max 15inthashCode()voidsetChannelId(String channelId) Channel to set featured workflows in.voidAuthentication token bearing required scopes.voidsetTriggerIds(List<String> triggerIds) Comma-separated array of trigger IDs that will replace any existing featured workflows in the channel; max 15toString()
-
Method Details
-
builder
-
getToken
Authentication token bearing required scopes.- Specified by:
getTokenin interfaceSlackApiRequest- Returns:
- token string value or null
-
getChannelId
Channel to set featured workflows in. -
getTriggerIds
Comma-separated array of trigger IDs that will replace any existing featured workflows in the channel; max 15 -
setToken
Authentication token bearing required scopes.- Specified by:
setTokenin interfaceSlackApiRequest
-
setChannelId
Channel to set featured workflows in. -
setTriggerIds
Comma-separated array of trigger IDs that will replace any existing featured workflows in the channel; max 15 -
equals
-
canEqual
-
hashCode
public int hashCode() -
toString
-